---
title: Agent-Model Orchestration in Multi-Agent Applications - Oct 15, 2024
---

### Speakers: Beibin Li

### Biography of the speakers:

Beibin Li is currently a Senior Research Engineer at Microsoft Research, where his work centers on AI and combinatorial optimization for cloud operations. Prior to joining MSR, he pursued a Ph.D. at the Paul G. Allen School of Computer Science and Engineering, University of Washington. During that time, he dedicated his research to developing a Unified Data Adaptation Framework for Neural Networks, with a particular focus on low-resource neural adaptation for histopathological images, eye tracking, autism behavior analyses, and database optimization. Beibin has won several awards in the past few years, including Best Paper at MLSys and Best Workshop Paper at ICLR, and has published in AI, ML, database, and systems.

### Abstract:

LLM agents are deeply connected with the underlying model. While state-of-the-art language models such as GPT-4o, o1, and Claude-3.5-sonnet perform well in many tasks, the design of agents is still deeply intertwined with their models.
Even with autonomous prompt optimization and existing orchestration frameworks, there remains much work to enable agents to perform long-trajectory planning and decision-making. This talk will focus on Reinforcement Learning for LLMs, decision-making, multimodal models, and synthesizing data to train LLM models for better agent-model orchestration.
